#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 120
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 60
#define ALIAS_COUNT 2
#define TOKEN_COUNT 30
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 2
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define PRODUCTION_ID_COUNT 4

enum {
  anon_sym_LBRACE = 1,
  anon_sym_COMMA = 2,
  anon_sym_RBRACE = 3,
  anon_sym_COLON = 4,
  anon_sym_LBRACK = 5,
  anon_sym_RBRACK = 6,
  anon_sym_DQUOTE = 7,
  aux_sym_string_content_token1 = 8,
  sym_escape_sequence = 9,
  sym_number = 10,
  sym_true = 11,
  sym_false = 12,
  sym_null = 13,
  sym_comment = 14,
  sym_rule_constant_exactly = 15,
  sym_rule_constant_prefix = 16,
  sym_rule_constant_suffix = 17,
  sym_rule_constant_equals_ignore_case = 18,
  sym_rule_constant_wildcard = 19,
  sym_rule_constant_anything_but = 20,
  sym_rule_constant_numeric = 21,
  sym_rule_constant_cidr = 22,
  sym_rule_constant_exists = 23,
  sym_rule_constant_or = 24,
  anon_sym_DQUOTE_LT_DQUOTE = 25,
  anon_sym_DQUOTE_GT_DQUOTE = 26,
  anon_sym_DQUOTE_LT_EQ_DQUOTE = 27,
  anon_sym_DQUOTE_GT_EQ_DQUOTE = 28,
  sym_rule_numeric_equality_sign = 29,
  sym_document = 30,
  sym__value = 31,
  sym_object = 32,
  sym_pair = 33,
  sym_array = 34,
  sym_string = 35,
  sym_string_content = 36,
  sym__rule_value_array = 37,
  sym_rule_value_matching = 38,
  sym_rule_exactly_matching = 39,
  sym_rule_prefix_matching = 40,
  sym_rule_suffix_matching = 41,
  sym_rule_equals_ignore_case_matching = 42,
  sym_rule_wildcard_matching = 43,
  sym_rule_anything_but_matching = 44,
  sym_rule_numeric_comparison_sign = 45,
  sym_rule_numeric_matching = 46,
  sym_rule_ip_address_matching = 47,
  sym_rule_exists_matching = 48,
  sym_rule_or_matching = 49,
  sym_boolean = 50,
  aux_sym_document_repeat1 = 51,
  aux_sym_object_repeat1 = 52,
  aux_sym_array_repeat1 = 53,
  aux_sym_string_content_repeat1 = 54,
  aux_sym__rule_value_array_repeat1 = 55,
  aux_sym__rule_value_array_repeat2 = 56,
  aux_sym_rule_numeric_matching_repeat1 = 57,
  aux_sym_rule_or_matching_repeat1 = 58,
  aux_sym_rule_or_matching_repeat2 = 59,
  alias_sym_rule_constant_value = 60,
  alias_sym_rule_nested_prefix_matching = 61,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_COLON] = ":",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_content_token1] = "string_content_token1",
  [sym_escape_sequence] = "escape_sequence",
  [sym_number] = "number",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [sym_comment] = "comment",
  [sym_rule_constant_exactly] = "rule_constant_exactly",
  [sym_rule_constant_prefix] = "rule_constant_prefix",
  [sym_rule_constant_suffix] = "rule_constant_suffix",
  [sym_rule_constant_equals_ignore_case] = "rule_constant_equals_ignore_case",
  [sym_rule_constant_wildcard] = "rule_constant_wildcard",
  [sym_rule_constant_anything_but] = "rule_constant_anything_but",
  [sym_rule_constant_numeric] = "rule_constant_numeric",
  [sym_rule_constant_cidr] = "rule_constant_cidr",
  [sym_rule_constant_exists] = "rule_constant_exists",
  [sym_rule_constant_or] = "rule_constant_or",
  [anon_sym_DQUOTE_LT_DQUOTE] = "\"<\"",
  [anon_sym_DQUOTE_GT_DQUOTE] = "\">\"",
  [anon_sym_DQUOTE_LT_EQ_DQUOTE] = "\"<=\"",
  [anon_sym_DQUOTE_GT_EQ_DQUOTE] = "\">=\"",
  [sym_rule_numeric_equality_sign] = "rule_numeric_equality_sign",
  [sym_document] = "document",
  [sym__value] = "_value",
  [sym_object] = "object",
  [sym_pair] = "pair",
  [sym_array] = "array",
  [sym_string] = "string",
  [sym_string_content] = "string_content",
  [sym__rule_value_array] = "array",
  [sym_rule_value_matching] = "rule_value_matching",
  [sym_rule_exactly_matching] = "rule_exactly_matching",
  [sym_rule_prefix_matching] = "rule_prefix_matching",
  [sym_rule_suffix_matching] = "rule_suffix_matching",
  [sym_rule_equals_ignore_case_matching] = "rule_equals_ignore_case_matching",
  [sym_rule_wildcard_matching] = "rule_wildcard_matching",
  [sym_rule_anything_but_matching] = "rule_anything_but_matching",
  [sym_rule_numeric_comparison_sign] = "rule_numeric_comparison_sign",
  [sym_rule_numeric_matching] = "rule_numeric_matching",
  [sym_rule_ip_address_matching] = "rule_ip_address_matching",
  [sym_rule_exists_matching] = "rule_exists_matching",
  [sym_rule_or_matching] = "rule_or_matching",
  [sym_boolean] = "boolean",
  [aux_sym_document_repeat1] = "document_repeat1",
  [aux_sym_object_repeat1] = "object_repeat1",
  [aux_sym_array_repeat1] = "array_repeat1",
  [aux_sym_string_content_repeat1] = "string_content_repeat1",
  [aux_sym__rule_value_array_repeat1] = "_rule_value_array_repeat1",
  [aux_sym__rule_value_array_repeat2] = "_rule_value_array_repeat2",
  [aux_sym_rule_numeric_matching_repeat1] = "rule_numeric_matching_repeat1",
  [aux_sym_rule_or_matching_repeat1] = "rule_or_matching_repeat1",
  [aux_sym_rule_or_matching_repeat2] = "rule_or_matching_repeat2",
  [alias_sym_rule_constant_value] = "rule_constant_value",
  [alias_sym_rule_nested_prefix_matching] = "rule_nested_prefix_matching",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_content_token1] = aux_sym_string_content_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_number] = sym_number,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [sym_comment] = sym_comment,
  [sym_rule_constant_exactly] = sym_rule_constant_exactly,
  [sym_rule_constant_prefix] = sym_rule_constant_prefix,
  [sym_rule_constant_suffix] = sym_rule_constant_suffix,
  [sym_rule_constant_equals_ignore_case] = sym_rule_constant_equals_ignore_case,
  [sym_rule_constant_wildcard] = sym_rule_constant_wildcard,
  [sym_rule_constant_anything_but] = sym_rule_constant_anything_but,
  [sym_rule_constant_numeric] = sym_rule_constant_numeric,
  [sym_rule_constant_cidr] = sym_rule_constant_cidr,
  [sym_rule_constant_exists] = sym_rule_constant_exists,
  [sym_rule_constant_or] = sym_rule_constant_or,
  [anon_sym_DQUOTE_LT_DQUOTE] = anon_sym_DQUOTE_LT_DQUOTE,
  [anon_sym_DQUOTE_GT_DQUOTE] = anon_sym_DQUOTE_GT_DQUOTE,
  [anon_sym_DQUOTE_LT_EQ_DQUOTE] = anon_sym_DQUOTE_LT_EQ_DQUOTE,
  [anon_sym_DQUOTE_GT_EQ_DQUOTE] = anon_sym_DQUOTE_GT_EQ_DQUOTE,
  [sym_rule_numeric_equality_sign] = sym_rule_numeric_equality_sign,
  [sym_document] = sym_document,
  [sym__value] = sym__value,
  [sym_object] = sym_object,
  [sym_pair] = sym_pair,
  [sym_array] = sym_array,
  [sym_string] = sym_string,
  [sym_string_content] = sym_string_content,
  [sym__rule_value_array] = sym_array,
  [sym_rule_value_matching] = sym_rule_value_matching,
  [sym_rule_exactly_matching] = sym_rule_exactly_matching,
  [sym_rule_prefix_matching] = sym_rule_prefix_matching,
  [sym_rule_suffix_matching] = sym_rule_suffix_matching,
  [sym_rule_equals_ignore_case_matching] = sym_rule_equals_ignore_case_matching,
  [sym_rule_wildcard_matching] = sym_rule_wildcard_matching,
  [sym_rule_anything_but_matching] = sym_rule_anything_but_matching,
  [sym_rule_numeric_comparison_sign] = sym_rule_numeric_comparison_sign,
  [sym_rule_numeric_matching] = sym_rule_numeric_matching,
  [sym_rule_ip_address_matching] = sym_rule_ip_address_matching,
  [sym_rule_exists_matching] = sym_rule_exists_matching,
  [sym_rule_or_matching] = sym_rule_or_matching,
  [sym_boolean] = sym_boolean,
  [aux_sym_document_repeat1] = aux_sym_document_repeat1,
  [aux_sym_object_repeat1] = aux_sym_object_repeat1,
  [aux_sym_array_repeat1] = aux_sym_array_repeat1,
  [aux_sym_string_content_repeat1] = aux_sym_string_content_repeat1,
  [aux_sym__rule_value_array_repeat1] = aux_sym__rule_value_array_repeat1,
  [aux_sym__rule_value_array_repeat2] = aux_sym__rule_value_array_repeat2,
  [aux_sym_rule_numeric_matching_repeat1] = aux_sym_rule_numeric_matching_repeat1,
  [aux_sym_rule_or_matching_repeat1] = aux_sym_rule_or_matching_repeat1,
  [aux_sym_rule_or_matching_repeat2] = aux_sym_rule_or_matching_repeat2,
  [alias_sym_rule_constant_value] = alias_sym_rule_constant_value,
  [alias_sym_rule_nested_prefix_matching] = alias_sym_rule_nested_prefix_matching,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_exactly] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_suffix] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_equals_ignore_case] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_anything_but] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_numeric] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_cidr] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_exists] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_constant_or] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE_LT_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_GT_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_LT_EQ_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_GT_EQ_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_rule_numeric_equality_sign] = {
    .visible = true,
    .named = true,
  },
  [sym_document] = {
    .visible = true,
    .named = true,
  },
  [sym__value] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__rule_value_array] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_value_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_exactly_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_prefix_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_suffix_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_equals_ignore_case_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_wildcard_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_anything_but_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_numeric_comparison_sign] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_numeric_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_ip_address_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_exists_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_rule_or_matching] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_document_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__rule_value_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__rule_value_array_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rule_numeric_matching_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rule_or_matching_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rule_or_matching_repeat2] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_rule_constant_value] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_rule_nested_prefix_matching] = {
    .visible = true,
    .named = true,
  },
};

enum {
  field_key = 1,
  field_value = 2,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_key] = "key",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_key, 0},
    {field_value, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [2] = {
    [0] = alias_sym_rule_constant_value,
  },
  [3] = {
    [3] = alias_sym_rule_nested_prefix_matching,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_string, 2,
    sym_string,
    alias_sym_rule_constant_value,
  sym_rule_prefix_matching, 2,
    sym_rule_prefix_matching,
    alias_sym_rule_nested_prefix_matching,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(103);
      if (lookahead == '"') ADVANCE(111);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(26);
      if (lookahead == '/') ADVANCE(19);
      if (lookahead == '0') ADVANCE(118);
      if (lookahead == ':') ADVANCE(107);
      if (lookahead == '[') ADVANCE(108);
      if (lookahead == '\\') ADVANCE(99);
      if (lookahead == ']') ADVANCE(109);
      if (lookahead == 'f') ADVANCE(28);
      if (lookahead == 'n') ADVANCE(91);
      if (lookahead == 't') ADVANCE(77);
      if (lookahead == '{') ADVANCE(104);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(101)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(119);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(12)
      if (lookahead == '"') ADVANCE(110);
      if (lookahead == '/') ADVANCE(112);
      if (lookahead == '\\') ADVANCE(99);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(115);
      if (lookahead != 0) ADVANCE(116);
      END_STATE();
    case 2:
      if (lookahead == '"') ADVANCE(136);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(134);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(135);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(128);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(129);
      END_STATE();
    case 7:
      if (lookahead == '"') ADVANCE(127);
      END_STATE();
    case 8:
      if (lookahead == '"') ADVANCE(133);
      END_STATE();
    case 9:
      if (lookahead == '"') ADVANCE(131);
      END_STATE();
    case 10:
      if (lookahead == '"') ADVANCE(132);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(130);
      END_STATE();
    case 12:
      if (lookahead == '"') ADVANCE(110);
      if (lookahead == '/') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(12)
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(27);
      if (lookahead == '/') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(13)
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(137);
      if (lookahead == '=') ADVANCE(17);
      END_STATE();
    case 15:
      if (lookahead == '"') ADVANCE(141);
      END_STATE();
    case 16:
      if (lookahead == '"') ADVANCE(138);
      if (lookahead == '=') ADVANCE(18);
      END_STATE();
    case 17:
      if (lookahead == '"') ADVANCE(139);
      END_STATE();
    case 18:
      if (lookahead == '"') ADVANCE(140);
      END_STATE();
    case 19:
      if (lookahead == '*') ADVANCE(21);
      if (lookahead == '/') ADVANCE(126);
      END_STATE();
    case 20:
      if (lookahead == '*') ADVANCE(20);
      if (lookahead == '/') ADVANCE(125);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 21:
      if (lookahead == '*') ADVANCE(20);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 22:
      if (lookahead == '-') ADVANCE(100);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(121);
      END_STATE();
    case 23:
      if (lookahead == '-') ADVANCE(33);
      END_STATE();
    case 24:
      if (lookahead == '-') ADVANCE(36);
      END_STATE();
    case 25:
      if (lookahead == '-') ADVANCE(56);
      END_STATE();
    case 26:
      if (lookahead == '0') ADVANCE(118);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(119);
      END_STATE();
    case 27:
      if (lookahead == '<') ADVANCE(14);
      if (lookahead == '=') ADVANCE(15);
      if (lookahead == '>') ADVANCE(16);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(60);
      END_STATE();
    case 29:
      if (lookahead == 'a') ADVANCE(35);
      if (lookahead == 'i') ADVANCE(82);
      END_STATE();
    case 30:
      if (lookahead == 'a') ADVANCE(76);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(64);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(84);
      END_STATE();
    case 33:
      if (lookahead == 'b') ADVANCE(93);
      END_STATE();
    case 34:
      if (lookahead == 'c') ADVANCE(30);
      END_STATE();
    case 35:
      if (lookahead == 'c') ADVANCE(87);
      END_STATE();
    case 36:
      if (lookahead == 'c') ADVANCE(32);
      END_STATE();
    case 37:
      if (lookahead == 'c') ADVANCE(8);
      END_STATE();
    case 38:
      if (lookahead == 'd') ADVANCE(34);
      END_STATE();
    case 39:
      if (lookahead == 'd') ADVANCE(75);
      END_STATE();
    case 40:
      if (lookahead == 'd') ADVANCE(9);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(122);
      END_STATE();
    case 42:
      if (lookahead == 'e') ADVANCE(123);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(24);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(78);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(11);
      END_STATE();
    case 47:
      if (lookahead == 'f') ADVANCE(54);
      END_STATE();
    case 48:
      if (lookahead == 'f') ADVANCE(59);
      END_STATE();
    case 49:
      if (lookahead == 'f') ADVANCE(48);
      END_STATE();
    case 50:
      if (lookahead == 'g') ADVANCE(23);
      END_STATE();
    case 51:
      if (lookahead == 'g') ADVANCE(69);
      END_STATE();
    case 52:
      if (lookahead == 'h') ADVANCE(55);
      END_STATE();
    case 53:
      if (lookahead == 'i') ADVANCE(39);
      END_STATE();
    case 54:
      if (lookahead == 'i') ADVANCE(95);
      END_STATE();
    case 55:
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 56:
      if (lookahead == 'i') ADVANCE(51);
      END_STATE();
    case 57:
      if (lookahead == 'i') ADVANCE(63);
      END_STATE();
    case 58:
      if (lookahead == 'i') ADVANCE(37);
      END_STATE();
    case 59:
      if (lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 60:
      if (lookahead == 'l') ADVANCE(83);
      END_STATE();
    case 61:
      if (lookahead == 'l') ADVANCE(124);
      END_STATE();
    case 62:
      if (lookahead == 'l') ADVANCE(98);
      END_STATE();
    case 63:
      if (lookahead == 'l') ADVANCE(38);
      END_STATE();
    case 64:
      if (lookahead == 'l') ADVANCE(80);
      END_STATE();
    case 65:
      if (lookahead == 'l') ADVANCE(61);
      END_STATE();
    case 66:
      if (lookahead == 'm') ADVANCE(45);
      END_STATE();
    case 67:
      if (lookahead == 'n') ADVANCE(97);
      END_STATE();
    case 68:
      if (lookahead == 'n') ADVANCE(50);
      END_STATE();
    case 69:
      if (lookahead == 'n') ADVANCE(71);
      END_STATE();
    case 70:
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 71:
      if (lookahead == 'o') ADVANCE(79);
      END_STATE();
    case 72:
      if (lookahead == 'q') ADVANCE(94);
      if (lookahead == 'x') ADVANCE(29);
      END_STATE();
    case 73:
      if (lookahead == 'r') ADVANCE(43);
      END_STATE();
    case 74:
      if (lookahead == 'r') ADVANCE(2);
      END_STATE();
    case 75:
      if (lookahead == 'r') ADVANCE(3);
      END_STATE();
    case 76:
      if (lookahead == 'r') ADVANCE(40);
      END_STATE();
    case 77:
      if (lookahead == 'r') ADVANCE(92);
      END_STATE();
    case 78:
      if (lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 79:
      if (lookahead == 'r') ADVANCE(44);
      END_STATE();
    case 80:
      if (lookahead == 's') ADVANCE(25);
      END_STATE();
    case 81:
      if (lookahead == 's') ADVANCE(4);
      END_STATE();
    case 82:
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 83:
      if (lookahead == 's') ADVANCE(42);
      END_STATE();
    case 84:
      if (lookahead == 's') ADVANCE(46);
      END_STATE();
    case 85:
      if (lookahead == 't') ADVANCE(52);
      END_STATE();
    case 86:
      if (lookahead == 't') ADVANCE(81);
      END_STATE();
    case 87:
      if (lookahead == 't') ADVANCE(62);
      END_STATE();
    case 88:
      if (lookahead == 't') ADVANCE(10);
      END_STATE();
    case 89:
      if (lookahead == 'u') ADVANCE(66);
      END_STATE();
    case 90:
      if (lookahead == 'u') ADVANCE(49);
      END_STATE();
    case 91:
      if (lookahead == 'u') ADVANCE(65);
      END_STATE();
    case 92:
      if (lookahead == 'u') ADVANCE(41);
      END_STATE();
    case 93:
      if (lookahead == 'u') ADVANCE(88);
      END_STATE();
    case 94:
      if (lookahead == 'u') ADVANCE(31);
      END_STATE();
    case 95:
      if (lookahead == 'x') ADVANCE(5);
      END_STATE();
    case 96:
      if (lookahead == 'x') ADVANCE(6);
      END_STATE();
    case 97:
      if (lookahead == 'y') ADVANCE(85);
      END_STATE();
    case 98:
      if (lookahead == 'y') ADVANCE(7);
      END_STATE();
    case 99:
      if (lookahead == '"' ||
          lookahead == '/' ||
          lookahead == '\\' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          lookahead == 't' ||
          lookahead == 'u') ADVANCE(117);
      END_STATE();
    case 100:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(121);
      END_STATE();
    case 101:
      if (eof) ADVANCE(103);
      if (lookahead == '"') ADVANCE(111);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(26);
      if (lookahead == '/') ADVANCE(19);
      if (lookahead == '0') ADVANCE(118);
      if (lookahead == ':') ADVANCE(107);
      if (lookahead == '[') ADVANCE(108);
      if (lookahead == ']') ADVANCE(109);
      if (lookahead == 'f') ADVANCE(28);
      if (lookahead == 'n') ADVANCE(91);
      if (lookahead == 't') ADVANCE(77);
      if (lookahead == '{') ADVANCE(104);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(101)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(119);
      END_STATE();
    case 102:
      if (eof) ADVANCE(103);
      if (lookahead == '"') ADVANCE(110);
      if (lookahead == ',') ADVANCE(105);
      if (lookahead == '-') ADVANCE(26);
      if (lookahead == '/') ADVANCE(19);
      if (lookahead == '0') ADVANCE(118);
      if (lookahead == ':') ADVANCE(107);
      if (lookahead == '[') ADVANCE(108);
      if (lookahead == ']') ADVANCE(109);
      if (lookahead == 'f') ADVANCE(28);
      if (lookahead == 'n') ADVANCE(91);
      if (lookahead == 't') ADVANCE(77);
      if (lookahead == '{') ADVANCE(104);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(102)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(119);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '$') ADVANCE(70);
      if (lookahead == 'a') ADVANCE(67);
      if (lookahead == 'c') ADVANCE(53);
      if (lookahead == 'e') ADVANCE(72);
      if (lookahead == 'n') ADVANCE(89);
      if (lookahead == 'p') ADVANCE(73);
      if (lookahead == 's') ADVANCE(90);
      if (lookahead == 'w') ADVANCE(57);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      if (lookahead == '*') ADVANCE(114);
      if (lookahead == '/') ADVANCE(116);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(116);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      if (lookahead == '*') ADVANCE(113);
      if (lookahead == '/') ADVANCE(116);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(114);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      if (lookahead == '*') ADVANCE(113);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(114);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      if (lookahead == '/') ADVANCE(112);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(115);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(116);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(aux_sym_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(116);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(120);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(22);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(120);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(119);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(120);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(121);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(126);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(sym_rule_constant_exactly);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_rule_constant_prefix);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(sym_rule_constant_suffix);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(sym_rule_constant_equals_ignore_case);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_rule_constant_wildcard);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_rule_constant_anything_but);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_rule_constant_numeric);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_rule_constant_cidr);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_rule_constant_exists);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_rule_constant_or);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_DQUOTE_LT_DQUOTE);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_DQUOTE_GT_DQUOTE);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_DQUOTE_LT_EQ_DQUOTE);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_DQUOTE_GT_EQ_DQUOTE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(sym_rule_numeric_equality_sign);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 102},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 0},
  [4] = {.lex_state = 102},
  [5] = {.lex_state = 102},
  [6] = {.lex_state = 102},
  [7] = {.lex_state = 102},
  [8] = {.lex_state = 102},
  [9] = {.lex_state = 102},
  [10] = {.lex_state = 102},
  [11] = {.lex_state = 102},
  [12] = {.lex_state = 102},
  [13] = {.lex_state = 102},
  [14] = {.lex_state = 102},
  [15] = {.lex_state = 102},
  [16] = {.lex_state = 102},
  [17] = {.lex_state = 102},
  [18] = {.lex_state = 102},
  [19] = {.lex_state = 102},
  [20] = {.lex_state = 13},
  [21] = {.lex_state = 102},
  [22] = {.lex_state = 13},
  [23] = {.lex_state = 1},
  [24] = {.lex_state = 1},
  [25] = {.lex_state = 1},
  [26] = {.lex_state = 102},
  [27] = {.lex_state = 0},
  [28] = {.lex_state = 0},
  [29] = {.lex_state = 0},
  [30] = {.lex_state = 0},
  [31] = {.lex_state = 0},
  [32] = {.lex_state = 0},
  [33] = {.lex_state = 0},
  [34] = {.lex_state = 0},
  [35] = {.lex_state = 0},
  [36] = {.lex_state = 0},
  [37] = {.lex_state = 0},
  [38] = {.lex_state = 0},
  [39] = {.lex_state = 0},
  [40] = {.lex_state = 0},
  [41] = {.lex_state = 102},
  [42] = {.lex_state = 0},
  [43] = {.lex_state = 0},
  [44] = {.lex_state = 0},
  [45] = {.lex_state = 0},
  [46] = {.lex_state = 0},
  [47] = {.lex_state = 0},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 0},
  [50] = {.lex_state = 102},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 102},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 0},
  [55] = {.lex_state = 0},
  [56] = {.lex_state = 0},
  [57] = {.lex_state = 0},
  [58] = {.lex_state = 0},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 0},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 0},
  [63] = {.lex_state = 0},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 102},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 102},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 102},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 0},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 0},
  [81] = {.lex_state = 0},
  [82] = {.lex_state = 102},
  [83] = {.lex_state = 102},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 102},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 0},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 102},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 0},
  [105] = {.lex_state = 0},
  [106] = {.lex_state = 0},
  [107] = {.lex_state = 0},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 0},
  [110] = {.lex_state = 0},
  [111] = {.lex_state = 0},
  [112] = {.lex_state = 0},
  [113] = {.lex_state = 0},
  [114] = {.lex_state = 0},
  [115] = {.lex_state = 0},
  [116] = {.lex_state = 0},
  [117] = {.lex_state = 0},
  [118] = {.lex_state = 0},
  [119] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_rule_constant_exactly] = ACTIONS(1),
    [sym_rule_constant_prefix] = ACTIONS(1),
    [sym_rule_constant_suffix] = ACTIONS(1),
    [sym_rule_constant_equals_ignore_case] = ACTIONS(1),
    [sym_rule_constant_wildcard] = ACTIONS(1),
    [sym_rule_constant_anything_but] = ACTIONS(1),
    [sym_rule_constant_numeric] = ACTIONS(1),
    [sym_rule_constant_cidr] = ACTIONS(1),
    [sym_rule_constant_exists] = ACTIONS(1),
    [sym_rule_constant_or] = ACTIONS(1),
  },
  [1] = {
    [sym_document] = STATE(119),
    [sym__value] = STATE(4),
    [sym_object] = STATE(17),
    [sym_array] = STATE(17),
    [sym_string] = STATE(17),
    [aux_sym_document_repeat1] = STATE(4),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_LBRACK] = ACTIONS(9),
    [anon_sym_DQUOTE] = ACTIONS(11),
    [sym_number] = ACTIONS(13),
    [sym_true] = ACTIONS(13),
    [sym_false] = ACTIONS(13),
    [sym_null] = ACTIONS(13),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_RBRACE,
    ACTIONS(17), 1,
      anon_sym_DQUOTE,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      sym_rule_constant_exactly,
    ACTIONS(23), 1,
      sym_rule_constant_prefix,
    ACTIONS(25), 1,
      sym_rule_constant_suffix,
    ACTIONS(27), 1,
      sym_rule_constant_equals_ignore_case,
    ACTIONS(29), 1,
      sym_rule_constant_wildcard,
    ACTIONS(31), 1,
      sym_rule_constant_anything_but,
    ACTIONS(33), 1,
      sym_rule_constant_numeric,
    ACTIONS(35), 1,
      sym_rule_constant_cidr,
    ACTIONS(37), 1,
      sym_rule_constant_exists,
    ACTIONS(39), 1,
      sym_rule_constant_or,
    STATE(37), 1,
      sym_pair,
    STATE(98), 1,
      sym_string,
    STATE(89), 11,
      sym_rule_value_matching,
      sym_rule_exactly_matching,
      sym_rule_prefix_matching,
      sym_rule_suffix_matching,
      sym_rule_equals_ignore_case_matching,
      sym_rule_wildcard_matching,
      sym_rule_anything_but_matching,
      sym_rule_numeric_matching,
      sym_rule_ip_address_matching,
      sym_rule_exists_matching,
      sym_rule_or_matching,
  [62] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_DQUOTE,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      sym_rule_constant_exactly,
    ACTIONS(23), 1,
      sym_rule_constant_prefix,
    ACTIONS(25), 1,
      sym_rule_constant_suffix,
    ACTIONS(27), 1,
      sym_rule_constant_equals_ignore_case,
    ACTIONS(29), 1,
      sym_rule_constant_wildcard,
    ACTIONS(31), 1,
      sym_rule_constant_anything_but,
    ACTIONS(33), 1,
      sym_rule_constant_numeric,
    ACTIONS(35), 1,
      sym_rule_constant_cidr,
    ACTIONS(37), 1,
      sym_rule_constant_exists,
    ACTIONS(39), 1,
      sym_rule_constant_or,
    STATE(65), 1,
      sym_pair,
    STATE(98), 1,
      sym_string,
    STATE(89), 11,
      sym_rule_value_matching,
      sym_rule_exactly_matching,
      sym_rule_prefix_matching,
      sym_rule_suffix_matching,
      sym_rule_equals_ignore_case_matching,
      sym_rule_wildcard_matching,
      sym_rule_anything_but_matching,
      sym_rule_numeric_matching,
      sym_rule_ip_address_matching,
      sym_rule_exists_matching,
      sym_rule_or_matching,
  [121] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(41), 1,
      ts_builtin_sym_end,
    STATE(5), 2,
      sym__value,
      aux_sym_document_repeat1,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(13), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [152] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(43), 1,
      ts_builtin_sym_end,
    ACTIONS(45), 1,
      anon_sym_LBRACE,
    ACTIONS(48), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      anon_sym_DQUOTE,
    STATE(5), 2,
      sym__value,
      aux_sym_document_repeat1,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(54), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [183] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 12,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [201] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(59), 1,
      anon_sym_LBRACK,
    STATE(67), 1,
      sym__value,
    STATE(69), 1,
      sym__rule_value_array,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(13), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [231] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(61), 1,
      anon_sym_RBRACK,
    STATE(30), 1,
      sym__value,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(13), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [261] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(61), 1,
      anon_sym_RBRACK,
    ACTIONS(63), 1,
      sym_number,
    ACTIONS(65), 1,
      sym_null,
    STATE(30), 1,
      sym__value,
    STATE(35), 1,
      sym_string,
    ACTIONS(13), 2,
      sym_true,
      sym_false,
    STATE(17), 2,
      sym_object,
      sym_array,
  [297] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 12,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [332] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [366] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(70), 1,
      sym__value,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(13), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [393] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [444] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 11,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DQUOTE,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [461] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(9), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(67), 1,
      sym__value,
    STATE(17), 3,
      sym_object,
      sym_array,
      sym_string,
    ACTIONS(13), 4,
      sym_number,
      sym_true,
      sym_false,
      sym_null,
  [488] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(85), 1,
      sym_rule_numeric_equality_sign,
    STATE(116), 1,
      sym_rule_numeric_comparison_sign,
    ACTIONS(83), 4,
      anon_sym_DQUOTE_LT_DQUOTE,
      anon_sym_DQUOTE_GT_DQUOTE,
      anon_sym_DQUOTE_LT_EQ_DQUOTE,
      anon_sym_DQUOTE_GT_EQ_DQUOTE,
  [504] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(87), 1,
      anon_sym_LBRACE,
    ACTIONS(89), 1,
      anon_sym_LBRACK,
    ACTIONS(91), 1,
      sym_number,
    STATE(58), 2,
      sym_string,
      sym__rule_value_array,
  [524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(115), 1,
      sym_rule_numeric_comparison_sign,
    ACTIONS(83), 4,
      anon_sym_DQUOTE_LT_DQUOTE,
      anon_sym_DQUOTE_GT_DQUOTE,
      anon_sym_DQUOTE_LT_EQ_DQUOTE,
      anon_sym_DQUOTE_GT_EQ_DQUOTE,
  [537] = 5,
    ACTIONS(93), 1,
      anon_sym_DQUOTE,
    ACTIONS(97), 1,
      sym_comment,
    STATE(25), 1,
      aux_sym_string_content_repeat1,
    STATE(101), 1,
      sym_string_content,
    ACTIONS(95), 2,
      aux_sym_string_content_token1,
      sym_escape_sequence,
  [554] = 4,
    ACTIONS(97), 1,
      sym_comment,
    ACTIONS(99), 1,
      anon_sym_DQUOTE,
    STATE(24), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(101), 2,
      aux_sym_string_content_token1,
      sym_escape_sequence,
  [568] = 4,
    ACTIONS(97), 1,
      sym_comment,
    ACTIONS(104), 1,
      anon_sym_DQUOTE,
    STATE(24), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(106), 2,
      aux_sym_string_content_token1,
      sym_escape_sequence,
  [582] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    ACTIONS(108), 1,
      sym_number,
    ACTIONS(110), 1,
      sym_null,
    STATE(32), 1,
      sym_string,
  [598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(112), 1,
      anon_sym_COMMA,
    ACTIONS(114), 1,
      anon_sym_RBRACK,
    STATE(51), 1,
      aux_sym_rule_numeric_matching_repeat1,
  [611] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(116), 1,
      anon_sym_COMMA,
    ACTIONS(119), 1,
      anon_sym_RBRACK,
    STATE(36), 1,
      aux_sym__rule_value_array_repeat1,
  [624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(122), 1,
      anon_sym_COMMA,
    ACTIONS(125), 1,
      anon_sym_RBRACK,
    STATE(29), 1,
      aux_sym_rule_numeric_matching_repeat1,
  [637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(127), 1,
      anon_sym_COMMA,
    ACTIONS(129), 1,
      anon_sym_RBRACK,
    STATE(46), 1,
      aux_sym_array_repeat1,
  [650] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(131), 1,
      anon_sym_COMMA,
    ACTIONS(133), 1,
      anon_sym_RBRACK,
    STATE(44), 1,
      aux_sym_rule_or_matching_repeat1,
  [663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_COMMA,
    ACTIONS(137), 1,
      anon_sym_RBRACK,
    STATE(40), 1,
      aux_sym__rule_value_array_repeat2,
  [676] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 1,
      anon_sym_RBRACK,
    ACTIONS(139), 1,
      anon_sym_COMMA,
    STATE(36), 1,
      aux_sym__rule_value_array_repeat1,
  [689] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(141), 1,
      anon_sym_COMMA,
    ACTIONS(144), 1,
      anon_sym_RBRACK,
    STATE(34), 1,
      aux_sym_array_repeat1,
  [702] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(119), 1,
      anon_sym_RBRACK,
    ACTIONS(146), 1,
      anon_sym_COMMA,
    STATE(40), 1,
      aux_sym__rule_value_array_repeat2,
  [715] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(139), 1,
      anon_sym_COMMA,
    ACTIONS(149), 1,
      anon_sym_RBRACK,
    STATE(45), 1,
      aux_sym__rule_value_array_repeat1,
  [728] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(151), 1,
      anon_sym_COMMA,
    ACTIONS(153), 1,
      anon_sym_RBRACE,
    STATE(42), 1,
      aux_sym_object_repeat1,
  [741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(62), 1,
      sym_boolean,
    ACTIONS(155), 2,
      sym_true,
      sym_false,
  [752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(157), 1,
      anon_sym_COMMA,
    ACTIONS(160), 1,
      anon_sym_RBRACE,
    STATE(39), 1,
      aux_sym_object_repeat1,
  [765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_COMMA,
    ACTIONS(149), 1,
      anon_sym_RBRACK,
    STATE(47), 1,
      aux_sym__rule_value_array_repeat2,
  [778] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(79), 1,
      sym_rule_value_matching,
    STATE(103), 1,
      sym_string,
  [791] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(151), 1,
      anon_sym_COMMA,
    ACTIONS(162), 1,
      anon_sym_RBRACE,
    STATE(39), 1,
      aux_sym_object_repeat1,
  [804] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(164), 1,
      anon_sym_COMMA,
    ACTIONS(166), 1,
      anon_sym_RBRACE,
    STATE(48), 1,
      aux_sym_rule_or_matching_repeat2,
  [817] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(131), 1,
      anon_sym_COMMA,
    ACTIONS(166), 1,
      anon_sym_RBRACK,
    STATE(49), 1,
      aux_sym_rule_or_matching_repeat1,
  [830] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(168), 1,
      anon_sym_COMMA,
    ACTIONS(171), 1,
      anon_sym_RBRACK,
    STATE(45), 1,
      aux_sym__rule_value_array_repeat1,
  [843] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(127), 1,
      anon_sym_COMMA,
    ACTIONS(173), 1,
      anon_sym_RBRACK,
    STATE(34), 1,
      aux_sym_array_repeat1,
  [856] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(175), 1,
      anon_sym_COMMA,
    ACTIONS(178), 1,
      anon_sym_RBRACK,
    STATE(47), 1,
      aux_sym__rule_value_array_repeat2,
  [869] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(180), 1,
      anon_sym_COMMA,
    ACTIONS(183), 1,
      anon_sym_RBRACE,
    STATE(48), 1,
      aux_sym_rule_or_matching_repeat2,
  [882] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_COMMA,
    ACTIONS(188), 1,
      anon_sym_RBRACK,
    STATE(49), 1,
      aux_sym_rule_or_matching_repeat1,
  [895] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(81), 1,
      sym_rule_value_matching,
    STATE(103), 1,
      sym_string,
  [908] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(112), 1,
      anon_sym_COMMA,
    ACTIONS(190), 1,
      anon_sym_RBRACK,
    STATE(29), 1,
      aux_sym_rule_numeric_matching_repeat1,
  [921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(66), 1,
      sym_string,
  [931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(192), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [939] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(194), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [947] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(196), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(198), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      sym_rule_constant_prefix,
    STATE(95), 1,
      sym_rule_prefix_matching,
  [973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(200), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [981] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(202), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [989] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(204), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(208), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(210), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [1021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(31), 1,
      sym_object,
  [1031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(212), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(218), 1,
      anon_sym_LBRACK,
  [1065] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(220), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1073] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(144), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [1081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(60), 1,
      sym_string,
  [1091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(222), 1,
      anon_sym_LBRACK,
    ACTIONS(224), 1,
      sym_number,
  [1101] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(226), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(56), 1,
      sym_string,
  [1119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(228), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(55), 1,
      sym_string,
  [1137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(188), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [1145] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(230), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(183), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(178), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [1169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(164), 1,
      anon_sym_COMMA,
    STATE(43), 1,
      aux_sym_rule_or_matching_repeat2,
  [1179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(54), 1,
      sym_string,
  [1189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(86), 1,
      sym_string,
  [1199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_COMMA,
    ACTIONS(119), 1,
      anon_sym_RBRACK,
  [1209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(232), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(234), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(171), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [1233] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(236), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1241] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(238), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_DQUOTE,
    STATE(80), 1,
      sym_string,
  [1259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(240), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [1267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(77), 1,
      sym_object,
  [1277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      anon_sym_LBRACK,
    STATE(69), 1,
      sym__rule_value_array,
  [1287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(242), 1,
      anon_sym_COLON,
  [1294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_RBRACE,
  [1301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(246), 1,
      anon_sym_COLON,
  [1308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(248), 1,
      sym_number,
  [1315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(250), 1,
      anon_sym_COLON,
  [1322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(252), 1,
      anon_sym_COLON,
  [1329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(254), 1,
      sym_number,
  [1336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(256), 1,
      anon_sym_DQUOTE,
  [1343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(258), 1,
      anon_sym_COLON,
  [1350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_COLON,
  [1357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      anon_sym_COLON,
  [1364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(114), 1,
      anon_sym_RBRACK,
  [1371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(264), 1,
      anon_sym_COLON,
  [1378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(266), 1,
      sym_number,
  [1385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 1,
      anon_sym_RBRACK,
  [1392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(268), 1,
      anon_sym_COLON,
  [1399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(270), 1,
      anon_sym_COMMA,
  [1406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(272), 1,
      anon_sym_COLON,
  [1413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(274), 1,
      anon_sym_COMMA,
  [1420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(276), 1,
      anon_sym_COLON,
  [1427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(278), 1,
      anon_sym_COLON,
  [1434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(280), 1,
      anon_sym_COMMA,
  [1441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_COMMA,
  [1448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(284), 1,
      anon_sym_COLON,
  [1455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(286), 1,
      sym_number,
  [1462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(288), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 62,
  [SMALL_STATE(4)] = 121,
  [SMALL_STATE(5)] = 152,
  [SMALL_STATE(6)] = 183,
  [SMALL_STATE(7)] = 201,
  [SMALL_STATE(8)] = 231,
  [SMALL_STATE(9)] = 261,
  [SMALL_STATE(10)] = 297,
  [SMALL_STATE(11)] = 315,
  [SMALL_STATE(12)] = 332,
  [SMALL_STATE(13)] = 349,
  [SMALL_STATE(14)] = 366,
  [SMALL_STATE(15)] = 393,
  [SMALL_STATE(16)] = 410,
  [SMALL_STATE(17)] = 427,
  [SMALL_STATE(18)] = 444,
  [SMALL_STATE(19)] = 461,
  [SMALL_STATE(20)] = 488,
  [SMALL_STATE(21)] = 504,
  [SMALL_STATE(22)] = 524,
  [SMALL_STATE(23)] = 537,
  [SMALL_STATE(24)] = 554,
  [SMALL_STATE(25)] = 568,
  [SMALL_STATE(26)] = 582,
  [SMALL_STATE(27)] = 598,
  [SMALL_STATE(28)] = 611,
  [SMALL_STATE(29)] = 624,
  [SMALL_STATE(30)] = 637,
  [SMALL_STATE(31)] = 650,
  [SMALL_STATE(32)] = 663,
  [SMALL_STATE(33)] = 676,
  [SMALL_STATE(34)] = 689,
  [SMALL_STATE(35)] = 702,
  [SMALL_STATE(36)] = 715,
  [SMALL_STATE(37)] = 728,
  [SMALL_STATE(38)] = 741,
  [SMALL_STATE(39)] = 752,
  [SMALL_STATE(40)] = 765,
  [SMALL_STATE(41)] = 778,
  [SMALL_STATE(42)] = 791,
  [SMALL_STATE(43)] = 804,
  [SMALL_STATE(44)] = 817,
  [SMALL_STATE(45)] = 830,
  [SMALL_STATE(46)] = 843,
  [SMALL_STATE(47)] = 856,
  [SMALL_STATE(48)] = 869,
  [SMALL_STATE(49)] = 882,
  [SMALL_STATE(50)] = 895,
  [SMALL_STATE(51)] = 908,
  [SMALL_STATE(52)] = 921,
  [SMALL_STATE(53)] = 931,
  [SMALL_STATE(54)] = 939,
  [SMALL_STATE(55)] = 947,
  [SMALL_STATE(56)] = 955,
  [SMALL_STATE(57)] = 963,
  [SMALL_STATE(58)] = 973,
  [SMALL_STATE(59)] = 981,
  [SMALL_STATE(60)] = 989,
  [SMALL_STATE(61)] = 997,
  [SMALL_STATE(62)] = 1005,
  [SMALL_STATE(63)] = 1013,
  [SMALL_STATE(64)] = 1021,
  [SMALL_STATE(65)] = 1031,
  [SMALL_STATE(66)] = 1039,
  [SMALL_STATE(67)] = 1047,
  [SMALL_STATE(68)] = 1055,
  [SMALL_STATE(69)] = 1065,
  [SMALL_STATE(70)] = 1073,
  [SMALL_STATE(71)] = 1081,
  [SMALL_STATE(72)] = 1091,
  [SMALL_STATE(73)] = 1101,
  [SMALL_STATE(74)] = 1109,
  [SMALL_STATE(75)] = 1119,
  [SMALL_STATE(76)] = 1127,
  [SMALL_STATE(77)] = 1137,
  [SMALL_STATE(78)] = 1145,
  [SMALL_STATE(79)] = 1153,
  [SMALL_STATE(80)] = 1161,
  [SMALL_STATE(81)] = 1169,
  [SMALL_STATE(82)] = 1179,
  [SMALL_STATE(83)] = 1189,
  [SMALL_STATE(84)] = 1199,
  [SMALL_STATE(85)] = 1209,
  [SMALL_STATE(86)] = 1217,
  [SMALL_STATE(87)] = 1225,
  [SMALL_STATE(88)] = 1233,
  [SMALL_STATE(89)] = 1241,
  [SMALL_STATE(90)] = 1249,
  [SMALL_STATE(91)] = 1259,
  [SMALL_STATE(92)] = 1267,
  [SMALL_STATE(93)] = 1277,
  [SMALL_STATE(94)] = 1287,
  [SMALL_STATE(95)] = 1294,
  [SMALL_STATE(96)] = 1301,
  [SMALL_STATE(97)] = 1308,
  [SMALL_STATE(98)] = 1315,
  [SMALL_STATE(99)] = 1322,
  [SMALL_STATE(100)] = 1329,
  [SMALL_STATE(101)] = 1336,
  [SMALL_STATE(102)] = 1343,
  [SMALL_STATE(103)] = 1350,
  [SMALL_STATE(104)] = 1357,
  [SMALL_STATE(105)] = 1364,
  [SMALL_STATE(106)] = 1371,
  [SMALL_STATE(107)] = 1378,
  [SMALL_STATE(108)] = 1385,
  [SMALL_STATE(109)] = 1392,
  [SMALL_STATE(110)] = 1399,
  [SMALL_STATE(111)] = 1406,
  [SMALL_STATE(112)] = 1413,
  [SMALL_STATE(113)] = 1420,
  [SMALL_STATE(114)] = 1427,
  [SMALL_STATE(115)] = 1434,
  [SMALL_STATE(116)] = 1441,
  [SMALL_STATE(117)] = 1448,
  [SMALL_STATE(118)] = 1455,
  [SMALL_STATE(119)] = 1462,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [41] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 1),
  [43] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2),
  [45] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(2),
  [48] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(8),
  [51] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(23),
  [54] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(17),
  [57] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [67] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [69] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2),
  [71] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value, 1),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2),
  [101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 2), SHIFT_REPEAT(24),
  [104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_content, 1),
  [106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__value, 1), SHIFT(100),
  [119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__value, 1), SHIFT(88),
  [122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rule_numeric_matching_repeat1, 2), SHIFT_REPEAT(22),
  [125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rule_numeric_matching_repeat1, 2),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2), SHIFT_REPEAT(14),
  [144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__value, 1), SHIFT(90),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2), SHIFT_REPEAT(3),
  [160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__rule_value_array_repeat1, 2), SHIFT_REPEAT(100),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__rule_value_array_repeat1, 2),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__rule_value_array_repeat2, 2), SHIFT_REPEAT(90),
  [178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__rule_value_array_repeat2, 2),
  [180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rule_or_matching_repeat2, 2), SHIFT_REPEAT(41),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rule_or_matching_repeat2, 2),
  [185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rule_or_matching_repeat1, 2), SHIFT_REPEAT(92),
  [188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rule_or_matching_repeat1, 2),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_anything_but_matching, 5, .production_id = 3),
  [194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_suffix_matching, 3),
  [196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_equals_ignore_case_matching, 3),
  [198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_wildcard_matching, 3),
  [200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_anything_but_matching, 3),
  [202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_numeric_matching, 3),
  [204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_ip_address_matching, 3),
  [206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1),
  [208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_exists_matching, 3),
  [210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rule_numeric_matching_repeat1, 4),
  [212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_exactly_matching, 3),
  [214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, .production_id = 1),
  [216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_value_matching, 3, .production_id = 2),
  [222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_numeric_matching, 8),
  [228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_numeric_matching, 7),
  [230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_or_matching, 6),
  [232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__rule_value_array, 4),
  [234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_prefix_matching, 3),
  [236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__rule_value_array, 3),
  [238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 1),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_or_matching, 5),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule_numeric_comparison_sign, 1),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [288] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_eventrule(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
